;;; dired-conf.el --- dired and dired-x configs
;;;
;;; commentary:
;;; dired-x provides extra dired functions.
;;;
;;; This hides details and dotfiles by default.
;;; It lits directories first.
;;;
;;; /  -- Showhide dotfiles       h     -- Showhide details
;;; -  -- Parent directory        e     -- Shell command
;;; R  -- Move/rename             C-h m -- Show all bindings
;;;
;;; code:

(use-package dired-x
  :custom
  (dired-x-hands-off-my-keys nil)
  (dired-omit-files  "\\`[.]?#\\|\\`[.][.]?\\'\\|^\\..+$"))

(use-package dired
  :delight "Dired"

  :bind (("C-c d" . dired-jump)
	 :map dired-mode-map
	 ("/" . dired-omit-mode)
	 ("h" . dired-hide-details-mode)
	 ("-" . dired-up-directory)
	 ("e" . dired-do-async-shell-command))
  :hook (dired-mode . dired-hide-details-mode)
  :hook (dired-mode . dired-omit-mode)
  :custom 
   (dired-listing-switches "-al --group-directories-first")
   (dired-kill-when-opening-new-dired-buffer t))

(provide 'dired-conf)
;;; dired-conf.el ends here
