;;; gnus-conf.el --- knit's gnus config :3
;;;
;;; commentary:
;;; Gnus is configured for Mail and NNTP.
;;; I use IMAP SMTP and POP.
;;; I keep a record of sent mail in ~/.emacs.d/mail/sent
;;;
;;; h  -- Hide thread      s     -- Show thread
;;; F  -- Reply to news    R     -- Reply to mail
;;; ^  -- Show Groups      C-h m -- Show all keybindings
;;;
;;; TODO: write a function to toggle "showhide thread"
;;;
;;; code:

(use-package emacs
  :custom
 (user-full-name       my-name)
 (user-mail-address    my-email)
 (smtpmail-smtp-server my-smtp)
 (message-default-mail-headers (concat "FCC: " my-sent-mail))
 (send-mail-function     'smtpmail-send-it)
 (smtpmail-smtp-service   587)
 (mail-sources '((pop :server smtpmail-smtp-server
	              :user   user-mail-address))))

(use-package gnus
  :bind (("C-c n" . gnus)
	 :map gnus-summary-mode-map
	 ("h"   . gnus-summary-hide-thread)
	 ("s"   . gnus-summary-show-thread)
	 ("n"   . next-line)
	 ("p"   . previous-line)
	 ("M-n" . gnus-summary-next-article)
	 ("M-p" . gnus-summary-prev-article))
  :init
  
  :custom
   (gnus-select-method              `(nntp ,my-nntp))
   (gnus-secondary-select-methods   my-gnus-methods)
   (gnus-thread-hide-subtree        t)
   (gnus-newsgroup-maximum-articles 50)
   (gnus-summary-line-format        "%U%R%z %d  %-30n  %B%s\n")
   (gnus-article-time-format        "%d %b, %Y")
   (gnus-article-date-headers       'user-defined)
   (gnus-check-new-newsgroups       nil)
   (gnus-check-bogus-newsgroups     nil)
   (gnus-use-cross-reference        nil)
   (gnus-nov-is-evil                nil)
   (gnus-confirm-mail-reply-to-news nil)
   (gnus-directory    "~/.local/share/gnus")
   (gnus-startup-file "~/.local/share/gnus/newsrc")
   (gnus-init-file    "~/.local/share/gnus/gnus.el")
   (gnus-auto-expirable-newsgroups "nnmbox:mail")
   (gnus-always-read-dribble-file   t)
   (gnus-use-dribble-file           t))

;; keys didnt work on gnus, so maybe i need to do that here
(use-package gnus-sum
  :bind (:map gnus-summary-mode-map
	      ("h"   . gnus-summary-hide-thread)
	      ("s"   . gnus-summary-show-thread)
	      ("n"   . next-line)
	      ("p"   . previous-line)
	      ("C-c B" . gnus-bookmark-set)
	      ("C-c b" . gnus-bookmark-bmenu-list)
	      ("M-n" . gnus-summary-next-article)
	      ("M-p" . gnus-summary-prev-article)))

(provide 'gnus-conf)
;;; gnus-conf.el ends here
