;;; theme.el --- emacs color theme
;;;
;;; commentary:
;;; I mostly just use modus because i care about WCAG :3
;;; i install the newest modus from elpa.
;;; i use iosevka comfy, an iosevka fork by stavrou
;;; 
;;; code:

;; Let me use any theme.
(setq custom-safe-themes t)


;; FONTS
;; See ../docs/fonts.org for my notes on fonts.

;;  (set-face-attribute 'default   nil :font "Serif Mono")
;; DejaVu Sans Mono-16  - No serif-mono
;; IBM Plex Mono-15     - No serif-mono
;; Symbola              - Default Emacs font. No mono.
;; Terminus             - OTB support. PSF.

(defvar main-font   "Iosevka Comfy-16")
(defvar serif-font  "Iosevka Comfy Motion-16")
(defvar vari-font   "Iosevka Comfy Motion Duo-16")

(use-package emacs
  :custom-face
  (default            ((t (:font ,main-font))))
  (mode-line          ((t (:font ,serif-font))))
  (mode-line-inactive ((t (:font ,serif-font))))
  (variable-pitch     ((t (:font ,vari-font))))
  (fixed-pitch-serif  ((t (:font ,serif-font)))))

;; I want a variable pitch font on orgmode files.
(use-package variable-pitch
  :hook (org-mode text-mode))

;; Hide the line between frames.
(defun hide-border ()
  "Hide the vertical border between frames."
  (set-face-attribute 'vertical-border
		      nil :foreground (face-background 'fringe)))

;; Using modus themes uwu
;; I'm using the package cause it's newer than the built-in.
(use-package modus-themes
  :ensure t
  :demand t
  :init
  (setq modus-themes-to-toggle
	'(modus-operandi-tinted modus-vivendi-tinted))

  (setq
   modus-themes-paren-match '(bold)
   modus-themes-hl-line     '(accented intense underline))

  (setq modus-themes-italic-constructs t
	modus-themes-bold-constructs   t
	modus-themes-variable-pitch-ui t
	modus-themes-mixed-fonts       t)

  :config
  (setq modus-themes-common-palette-overrides
    `(,@modus-themes-preset-overrides-warmer

	  ;; active mode-line
	  (bg-mode-line-active       bg-sage)
	  (fg-mode-line-active       fg-main)
	  (border-mode-line-active   bg-sage)
	  (fg-window-divider-inner   fringe)

	  ;; inactive mode-line
	  (bg-mode-line-inactive     bg-dim)
	  (fg-mode-line-inactive     fg-dim)
	  (border-mode-line-inactive bg-dim)

	  ;; point
	  ;; magenta
	  (cursor magenta)

	  ;; org blocks
	  (bg-prose-block-contents bg-magenta-nuanced)
	  (bg-prose-block-delimiter bg-lavender)
	  (fg-prose-block-delimiter fg-main)))

  (setq modus-vivendi-tinted-palette-overrides
	`(,@modus-themes-preset-overrides-cooler
	  (bg-mode-line-active     bg-cyan-subtle)
	  (border-mode-line-active bg-cyan-subtle)))

  ;; Load both themes, but only enable one.
  (load-theme (car  modus-themes-to-toggle) t nil)
  (load-theme (cadr modus-themes-to-toggle) t t)

  :hook (modus-themes-post-load . hide-border))

(defun theme-replace (theme1 theme2)
  "Enable THEME1, disable THEME2, and hide the vertical border."
  (disable-theme theme2)
  (enable-theme theme1)
  (hide-border))

;; From the manual.
(defun my-modus-themes-toggle ()
  "Toggle between the two themes in 'modus-themes-to-toggle' via enable rather than load."
  (interactive)
  (let ((light (car  modus-themes-to-toggle))
	(dark  (cadr modus-themes-to-toggle)))
    (if (equal (modus-themes--current-theme) dark)
	(theme-replace light dark)
	(theme-replace dark light))))

(modus-themes--current-theme)

(provide 'theme)

;;; theme.el ends here
